@@ -7,7 +7,7 @@ import logging
 import sys
 from collections import OrderedDict
 from copy import deepcopy
-from datetime import datetime
+from datetime import datetime, date
 from os.path import join
 from typing import List, Union, Optional, Dict, Any, Tuple, Callable, Iterator, Iterable, Set
 
@@ -850,7 +850,7 @@ class Dataset(HDXObject):
         return cls._autocomplete(name, limit, configuration)
 
     def get_date_of_dataset(self, date_format=None, today=datetime.now()):
-        # type: (Optional[str], datetime.date) -> Dict
+        # type: (Optional[str], datetime) -> Dict
         """Get dataset date as datetimes and strings in specified format. If no format is supplied, the ISO 8601
         format is used. Returns a dictionary containing keys startdate (start date as datetime), enddate (end
         date as datetime), startdate_str (start date as string), enddate_str (end date as string) and ongoing
@@ -858,7 +858,7 @@ class Dataset(HDXObject):
 
         Args:
             date_format (Optional[str]): Date format. None is taken to be ISO 8601. Defaults to None.
-            today (datetime.date): Date to use for today. Defaults to datetime.now.
+            today (datetime): Date to use for today. Defaults to datetime.now.
 
         Returns:
             Dict: Dictionary of date information
@@ -866,11 +866,11 @@ class Dataset(HDXObject):
         return DateHelper.get_date_info(self.data.get('dataset_date'), date_format, today)
 
     def set_date_of_dataset(self, startdate, enddate=None, ongoing=False):
-        # type: (Union[datetime.datetime, str], Union[datetime, str, None], bool) -> None
+        # type: (Union[datetime, str], Union[datetime, str, None], bool) -> None
         """Set dataset date from either datetime.datetime objects or strings.
 
         Args:
-            startdate (Union[datetime.datetime, str]): Dataset start date
+            startdate (Union[datetime, str]): Dataset start date
             enddate (Union[datetime, str, None]): Dataset end date. Defaults to None.
             ongoing (bool): True if ongoing, False if not. Defaults to False.
 
@@ -1549,8 +1549,8 @@ class Dataset(HDXObject):
                     break
 
 
-    def _generate_resource_view(self, resource=0, path=None, bites_disabled=None, indicators=None):
-        # type: (Union[hdx.data.resource.Resource,Dict,str,int], Optional[str], Optional[List[bool]], Optional[List[Dict]]) -> hdx.data.resource_view.ResourceView
+    def _generate_resource_view(self, resource=0, path=None, bites_disabled=None, indicators=None, findreplace=None):
+        # type: (Union[hdx.data.resource.Resource,Dict,str,int], Optional[str], Optional[List[bool]], Optional[List[Dict]], Optional[Dict]) -> hdx.data.resource_view.ResourceView
         """Create QuickCharts for dataset from configuration saved in resource view. You can disable specific bites
         by providing bites_disabled, a list of 3 bools where True indicates a specific bite is disabled and False
         indicates leave enabled. If you supply indicators, then the internal indicators resource view template will be
@@ -1564,6 +1564,7 @@ class Dataset(HDXObject):
             path (Optional[str]): Path to YAML resource view metadata. Defaults to None (config/hdx_resource_view_static.yml or internal template).
             bites_disabled (Optional[List[bool]]): Which QC bites should be disabled. Defaults to None (all bites enabled).
             indicators (Optional[List[Dict]]): Indicator codes, QC titles and units for resource view template. Defaults to None (don't use template).
+            findreplace (Optional[Dict]): Replacements for anything else in resource view. Defaults to None.
 
         Returns:
             hdx.data.resource_view.ResourceView: The resource view if QuickCharts created, None is not
@@ -1587,23 +1588,21 @@ class Dataset(HDXObject):
                 path = script_dir_plus_file('indicator_resource_view_template.yml', NotRequestableError)
         resourceview.update_from_yaml(path=path)
 
-        def replace_date_col(hxl_preview_cfg, ind, colno):
-            date_col_str = 'DATE_COL_%d' % colno
-            date_col = ind.get('date')
-            if date_col:
-                replace = date_col
-            else:
-                replace = '#date+year'
-            return replace_string(hxl_preview_cfg, date_col_str, replace)
+        def replace_string(instr, what, withwhat):
+            return instr.replace(what, str(withwhat))
 
-        def replace_aggregate_col(hxl_preview_cfg, ind, colno):
-            aggregate_col_str = 'AGGREGATE_COL_%d' % colno
-            aggregate_col = ind.get('aggregate')
-            if aggregate_col:
-                replace = '"%s"' % aggregate_col
+        defaults = {'code_col': '#indicator+code', 'value_col': '#indicator+value+num', 'date_col': '#date+year', 'aggregate_col': 'null'}
+
+        def replace_col(hxl_preview_cfg, col_str, ind, col, with_quotes=False):
+            if with_quotes:
+                col_str = '"%s"' % col_str
+            replace = ind.get(col)
+            if replace:
+                if with_quotes:
+                    replace = '"%s"' % replace
             else:
-                replace = 'null'
-            return replace_string(hxl_preview_cfg, aggregate_col_str, replace)
+                replace = defaults[col]
+            return replace_string(hxl_preview_cfg, col_str, replace)
 
         hxl_preview_config = resourceview['hxl_preview_config']
         if indicators is None:
@@ -1614,40 +1613,43 @@ class Dataset(HDXObject):
                 return None
             indicators_notexist = [True, True, True]
             if indicators[0]:
-                def replace_string(instr, what, withwhat):
-                    return instr.replace(what, str(withwhat))
-
                 indicator = indicators[0]
-                hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_CODE_1', str(indicator['code']))
+                hxl_preview_config = replace_string(hxl_preview_config, 'CODE_VALUE_1', str(indicator['code']))
                 replace = indicator.get('description', '')
-                hxl_preview_config = replace_string(hxl_preview_config, 'DESCRIPTION_1', replace)
-                hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_TITLE_1', indicator['title'])
+                hxl_preview_config = replace_string(hxl_preview_config, 'DESCRIPTION_VALUE_1', replace)
+                hxl_preview_config = replace_string(hxl_preview_config, 'TITLE_VALUE_1', indicator['title'])
                 replace = indicator.get('unit', '')
-                hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_UNIT_1', replace)
-                hxl_preview_config = replace_date_col(hxl_preview_config, indicator, 1)
-                hxl_preview_config = replace_aggregate_col(hxl_preview_config, indicator, 1)
+                hxl_preview_config = replace_string(hxl_preview_config, 'UNIT_VALUE_1', replace)
+                hxl_preview_config = replace_col(hxl_preview_config, 'CODE_COL_1', indicator, 'code_col')
+                hxl_preview_config = replace_col(hxl_preview_config, 'VALUE_COL_1', indicator, 'value_col')
+                hxl_preview_config = replace_col(hxl_preview_config, 'DATE_COL_1', indicator, 'date_col')
+                hxl_preview_config = replace_col(hxl_preview_config, 'AGGREGATE_COL_1', indicator, 'aggregate_col', True)
                 indicators_notexist[0] = False
             if len_indicators > 1 and indicators[1]:
                 indicator = indicators[1]
-                hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_CODE_2', str(indicator['code']))
+                hxl_preview_config = replace_string(hxl_preview_config, 'CODE_VALUE_2', str(indicator['code']))
                 replace = indicator.get('description', '')
-                hxl_preview_config = replace_string(hxl_preview_config, 'DESCRIPTION_2', replace)
-                hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_TITLE_2', indicator['title'])
+                hxl_preview_config = replace_string(hxl_preview_config, 'DESCRIPTION_VALUE_2', replace)
+                hxl_preview_config = replace_string(hxl_preview_config, 'TITLE_VALUE_2', indicator['title'])
                 replace = indicator.get('unit', '')
-                hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_UNIT_2', replace)
-                hxl_preview_config = replace_date_col(hxl_preview_config, indicator, 2)
-                hxl_preview_config = replace_aggregate_col(hxl_preview_config, indicator, 2)
+                hxl_preview_config = replace_string(hxl_preview_config, 'UNIT_VALUE_2', replace)
+                hxl_preview_config = replace_col(hxl_preview_config, 'CODE_COL_2', indicator, 'code_col')
+                hxl_preview_config = replace_col(hxl_preview_config, 'VALUE_COL_2', indicator, 'value_col')
+                hxl_preview_config = replace_col(hxl_preview_config, 'DATE_COL_2', indicator, 'date_col')
+                hxl_preview_config = replace_col(hxl_preview_config, 'AGGREGATE_COL_2', indicator, 'aggregate_col', True)
                 indicators_notexist[1] = False
             if len_indicators > 2 and indicators[2]:
                 indicator = indicators[2]
-                hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_CODE_3', str(indicator['code']))
+                hxl_preview_config = replace_string(hxl_preview_config, 'CODE_VALUE_3', str(indicator['code']))
                 replace = indicator.get('description', '')
-                hxl_preview_config = replace_string(hxl_preview_config, 'DESCRIPTION_3', replace)
-                hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_TITLE_3', indicator['title'])
+                hxl_preview_config = replace_string(hxl_preview_config, 'DESCRIPTION_VALUE_3', replace)
+                hxl_preview_config = replace_string(hxl_preview_config, 'TITLE_VALUE_3', indicator['title'])
                 replace = indicator.get('unit', '')
-                hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_UNIT_3', replace)
-                hxl_preview_config = replace_date_col(hxl_preview_config, indicator, 3)
-                hxl_preview_config = replace_aggregate_col(hxl_preview_config, indicator, 3)
+                hxl_preview_config = replace_string(hxl_preview_config, 'UNIT_VALUE_3', replace)
+                hxl_preview_config = replace_col(hxl_preview_config, 'CODE_COL_3', indicator, 'code_col')
+                hxl_preview_config = replace_col(hxl_preview_config, 'VALUE_COL_3', indicator, 'value_col')
+                hxl_preview_config = replace_col(hxl_preview_config, 'DATE_COL_3', indicator, 'date_col')
+                hxl_preview_config = replace_col(hxl_preview_config, 'AGGREGATE_COL_3', indicator, 'aggregate_col', True)
                 indicators_notexist[2] = False
             if indicators_notexist == [True, True, True]:
                 return None
@@ -1657,6 +1659,9 @@ class Dataset(HDXObject):
             if disable or indicators_notexist[i]:
                 del bites[i]
         hxl_preview_config = json.dumps(hxl_preview_config, indent=None, separators=(',', ':'))
+        if findreplace:
+            for find in findreplace:
+                hxl_preview_config = replace_string(hxl_preview_config, find, findreplace[find])
         resourceview['hxl_preview_config'] = hxl_preview_config
 
         if 'resource_id' in resourceview:
@@ -1666,8 +1671,8 @@ class Dataset(HDXObject):
             self.preview_resourceview = resourceview
         return resourceview
 
-    def generate_resource_view(self, resource=0, path=None, bites_disabled=None, indicators=None):
-        # type: (Union[hdx.data.resource.Resource,Dict,str,int], Optional[str], Optional[List[bool]], Optional[List[Dict]]) -> hdx.data.resource_view.ResourceView
+    def generate_resource_view(self, resource=0, path=None, bites_disabled=None, indicators=None, findreplace=None):
+        # type: (Union[hdx.data.resource.Resource,Dict,str,int], Optional[str], Optional[List[bool]], Optional[List[Dict]], Optional[Dict]) -> hdx.data.resource_view.ResourceView
         """Create QuickCharts for dataset from configuration saved in resource view. You can disable specific bites
         by providing bites_disabled, a list of 3 bools where True indicates a specific bite is disabled and False
         indicates leave enabled. If you supply indicators, then the internal indicators resource view template will be
@@ -1681,11 +1686,12 @@ class Dataset(HDXObject):
             path (Optional[str]): Path to YAML resource view metadata. Defaults to None (config/hdx_resource_view_static.yml or internal template).
             bites_disabled (Optional[List[bool]]): Which QC bites should be disabled. Defaults to None (all bites enabled).
             indicators (Optional[List[Dict]]): Indicator codes, QC titles and units for resource view template. Defaults to None (don't use template).
+            findreplace (Optional[Dict]): Replacements for anything else in resource view. Defaults to None.
 
         Returns:
             hdx.data.resource_view.ResourceView: The resource view if QuickCharts created, None is not
         """
-        resourceview = self._generate_resource_view(resource, path, bites_disabled, indicators)
+        resourceview = self._generate_resource_view(resource, path, bites_disabled, indicators, findreplace=findreplace)
         if resourceview is None:
             self.preview_off()
         return resourceview
